#[non_exhaustive]pub enum Hypercall<'a> {
Exit(i32),
FileClose(&'a mut CloseParams),
FileLseek(&'a mut LseekParams),
FileOpen(&'a mut OpenParams),
FileRead(&'a mut ReadParams),
FileWrite(&'a mut WriteParams),
FileUnlink(&'a mut UnlinkParams),
SerialWriteByte(u8),
SerialWriteBuffer(&'a SerialWriteBufferParams),
SerialReadByte,
SerialReadBuffer(&'a SerialReadBufferParams),
}Expand description
Hypervisor calls available in Uhyve with their respective parameters. See the module level documentation on how to invoke them.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exit(i32)
Exit the VM and return a status code.
FileClose(&'a mut CloseParams)
FileLseek(&'a mut LseekParams)
FileOpen(&'a mut OpenParams)
FileRead(&'a mut ReadParams)
FileWrite(&'a mut WriteParams)
FileUnlink(&'a mut UnlinkParams)
SerialWriteByte(u8)
Write a char to the terminal.
SerialWriteBuffer(&'a SerialWriteBufferParams)
Write a buffer to the terminal
SerialReadByte
Read a single byte from the terminal
SerialReadBuffer(&'a SerialReadBufferParams)
Read a buffer from the terminal
Implementations