#[non_exhaustive]#[repr(u64)]pub enum HypercallAddress {
Show 13 variants
Exit = 4_112,
SerialWriteByte = 4_128,
SerialWriteBuffer = 4_144,
SerialReadByte = 4_160,
SerialReadBuffer = 4_176,
FileWrite = 4_352,
FileOpen = 4_368,
FileClose = 4_384,
FileRead = 4_400,
FileLseek = 4_416,
FileUnlink = 4_432,
SharedMemOpen = 4_608,
SharedMemClose = 4_624,
}Expand description
Enum containing all valid MMIO addresses for hypercalls.
The discriminants of this enum are the respective addresses, so one can get the code by calling
e.g., HypercallAddress::Exit as u64.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exit = 4_112
SerialWriteByte = 4_128
SerialWriteBuffer = 4_144
SerialReadByte = 4_160
SerialReadBuffer = 4_176
FileWrite = 4_352
FileOpen = 4_368
FileClose = 4_384
FileRead = 4_400
FileLseek = 4_416
FileUnlink = 4_432